@@ -10,10 +10,10 @@
 #'@keywords internal
 genparammatrix = function(parameters, levels, g) {
   if (parameters <= 0 | levels <= 0 | g < 0) {
-    stop("Number of parameters and levels must be non-zero, preceeding levels must be non-negative")
+    stop("skpr: Number of parameters and levels must be non-zero, preceeding levels must be non-negative")
   }
   if (parameters < levels) {
-    stop("Number of parameters must be greater than number of levels")
+    stop("skpr: Number of parameters must be greater than number of levels")
   }
   L = matrix(0, ncol = parameters, nrow = levels)
   L[, (g + 1):(g + levels)] = diag(levels)
